@@ -3,10 +3,10 @@ import asyncio
 from pymax import MaxClient
 from pymax.payloads import UserAgentPayload
 
-ua = UserAgentPayload(device_type="WEB")
+ua = UserAgentPayload(device_type="DESKTOP", app_version="25.12.13")
 
 client = MaxClient(
-    phone="+79911111111",
+    phone="+79116290861",
     work_dir="cache",
     headers=ua,
 )
